@@ -19,6 +19,36 @@ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
+
+This module contains functions for sizing and rating pressure relief valves.
+At present, this consists of several functions from API 520.
+
+For reporting bugs, adding feature requests, or submitting pull requests,
+please use the `GitHub issue tracker <https://github.com/CalebBell/fluids/>`_
+or contact the author at Caleb.Andrew.Bell@gmail.com.
+
+
+.. contents:: :local:
+
+Interfaces
+----------
+.. autofunction:: API520_A_g
+.. autofunction:: API520_A_steam
+
+Functions and Data
+------------------
+.. autofunction:: API520_round_size
+.. autofunction:: API520_C
+.. autofunction:: API520_F2
+.. autofunction:: API520_Kv
+.. autofunction:: API520_N
+.. autofunction:: API520_SH
+.. autofunction:: API520_B
+.. autofunction:: API520_W
+.. autodata:: API526_letters
+.. autodata:: API526_A_sq_inch
+.. autodata:: API526_A
+
 """
 
 from __future__ import division
@@ -34,9 +64,13 @@ __all__ = ['API526_A_sq_inch', 'API526_letters', 'API526_A',
 
 API526_A_sq_inch = [0.110, 0.196, 0.307, 0.503, 0.785, 1.287, 1.838, 2.853, 3.60,
              4.34, 6.38, 11.05, 16.00, 26.00] # square inches
+'''list: Nominal relief area in for different valve sizes in API 520, [in^2]'''
 API526_letters = ['D', 'E', 'F', 'G', 'H', 'J', 'K', 'L', 'M', 'N', 'P', 'Q', 'R','T']
-API526_A = [i*inch**2 for i in API526_A_sq_inch]
-
+'''list: Letter size designations for different valve sizes in API 520'''
+inch2 = inch*inch
+API526_A = [i*inch2 for i in API526_A_sq_inch]
+'''list: Nominal relief area in for different valve sizes in API 520, [m^2]'''
+del inch2
 
 def API520_round_size(A):
     r'''Rounds up the area from an API 520 calculation to an API526 standard
@@ -268,14 +302,14 @@ _KSH_psigs = [15, 20, 40, 60, 80, 100, 120, 140, 160, 180, 200, 220, 240, 260,
 _KSH_tempFs = [300, 400, 500, 600, 700, 800, 900, 1000, 1100, 1200]
 
 # _KSH_psigs converted from psig to Pa
-_KSH_Pa = [204746.3593975254, 239220.14586336722, 377115.29172673443, 
+_KSH_Pa = [204746.3593975254, 239220.14586336722, 377115.29172673443,
            515010.4375901016, 652905.5834534689, 790800.7293168361,
            928695.8751802032, 1066591.0210435705, 1204486.1669069377,
-           1342381.312770305, 1480276.4586336722, 1618171.6044970395, 
-           1756066.7503604065, 1893961.8962237737, 2031857.042087141, 
-           2169752.187950508, 2514490.0526089263, 2859227.9172673444, 
+           1342381.312770305, 1480276.4586336722, 1618171.6044970395,
+           1756066.7503604065, 1893961.8962237737, 2031857.042087141,
+           2169752.187950508, 2514490.0526089263, 2859227.9172673444,
            3548703.64658418, 4238179.375901016, 5617130.834534689,
-           6996082.29316836, 8719771.616460452, 10443460.939752541, 
+           6996082.29316836, 8719771.616460452, 10443460.939752541,
            12167150.263044631, 13890839.58633672, 17338218.232920904,
            20785596.879505083]
 
@@ -364,18 +398,18 @@ def API520_SH(T1, P1):
 
 
 # Kw, for liquids. Applicable for all overpressures.
-Kw_x = [15., 16.5493, 17.3367, 18.124, 18.8235, 19.5231, 20.1351, 20.8344, 
-        21.4463, 22.0581, 22.9321, 23.5439, 24.1556, 24.7674, 25.0296, 25.6414, 
-        26.2533, 26.8651, 27.7393, 28.3511, 28.9629, 29.6623, 29.9245, 30.5363, 
+Kw_x = [15., 16.5493, 17.3367, 18.124, 18.8235, 19.5231, 20.1351, 20.8344,
+        21.4463, 22.0581, 22.9321, 23.5439, 24.1556, 24.7674, 25.0296, 25.6414,
+        26.2533, 26.8651, 27.7393, 28.3511, 28.9629, 29.6623, 29.9245, 30.5363,
         31.2357, 31.8475, 32.7217, 33.3336, 34.0329, 34.6448, 34.8196, 35.4315,
-        36.1308, 36.7428, 37.7042, 38.3162, 39.0154, 39.7148, 40.3266, 40.9384, 
+        36.1308, 36.7428, 37.7042, 38.3162, 39.0154, 39.7148, 40.3266, 40.9384,
         41.6378, 42.7742, 43.386, 43.9978, 44.6098, 45.2216, 45.921, 46.5329,
         47.7567, 48.3685, 49.0679, 49.6797, 50.]
 Kw_y = [1, 0.996283, 0.992565, 0.987918, 0.982342, 0.976766, 0.97119, 0.964684,
         0.958178, 0.951673, 0.942379, 0.935874, 0.928439, 0.921933, 0.919145,
-        0.912639, 0.906134, 0.899628, 0.891264, 0.884758, 0.878253, 0.871747, 
-        0.868959, 0.862454, 0.855948, 0.849442, 0.841078, 0.834572, 0.828067, 
-        0.821561, 0.819703, 0.814126, 0.806691, 0.801115, 0.790892, 0.785316, 
+        0.912639, 0.906134, 0.899628, 0.891264, 0.884758, 0.878253, 0.871747,
+        0.868959, 0.862454, 0.855948, 0.849442, 0.841078, 0.834572, 0.828067,
+        0.821561, 0.819703, 0.814126, 0.806691, 0.801115, 0.790892, 0.785316,
         0.777881, 0.771375, 0.76487, 0.758364, 0.751859, 0.740706, 0.734201,
         0.727695, 0.722119, 0.715613, 0.709108, 0.702602, 0.69052, 0.684015,
         0.677509, 0.671004, 0.666357]
@@ -424,29 +458,29 @@ def API520_W(Pset, Pback):
 
 
 # Kb Backpressure correction factor, for gases
-Kb_16_over_x = [37.6478, 38.1735, 38.6991, 39.2904, 39.8817, 40.4731, 40.9987, 
-                41.59, 42.1156, 42.707, 43.2326, 43.8239, 44.4152, 44.9409, 
-                45.5322, 46.0578, 46.6491, 47.2405, 47.7661, 48.3574, 48.883, 
+Kb_16_over_x = [37.6478, 38.1735, 38.6991, 39.2904, 39.8817, 40.4731, 40.9987,
+                41.59, 42.1156, 42.707, 43.2326, 43.8239, 44.4152, 44.9409,
+                45.5322, 46.0578, 46.6491, 47.2405, 47.7661, 48.3574, 48.883,
                 49.4744, 50.0]
-Kb_16_over_y = [0.998106, 0.994318, 0.99053, 0.985795, 0.982008, 0.97822, 
-                0.973485, 0.96875, 0.964962, 0.961174, 0.956439, 0.951705, 
+Kb_16_over_y = [0.998106, 0.994318, 0.99053, 0.985795, 0.982008, 0.97822,
+                0.973485, 0.96875, 0.964962, 0.961174, 0.956439, 0.951705,
                 0.947917, 0.943182, 0.939394, 0.935606, 0.930871, 0.926136,
                 0.921402, 0.918561, 0.913826, 0.910038, 0.90625]
 
 Kb_10_over_x = [30.0263, 30.6176, 31.1432, 31.6689, 32.1945, 32.6544, 33.18,
-                33.7057, 34.1656, 34.6255, 35.0854, 35.5453, 36.0053, 36.4652, 
+                33.7057, 34.1656, 34.6255, 35.0854, 35.5453, 36.0053, 36.4652,
                 36.9251, 37.385, 37.8449, 38.2392, 38.6334, 39.0276, 39.4875,
-                39.9474, 40.4074, 40.8016, 41.1958, 41.59, 42.0499, 42.4442, 
-                42.8384, 43.2326, 43.6925, 44.0867, 44.4809, 44.8752, 45.2694, 
+                39.9474, 40.4074, 40.8016, 41.1958, 41.59, 42.0499, 42.4442,
+                42.8384, 43.2326, 43.6925, 44.0867, 44.4809, 44.8752, 45.2694,
                 45.6636, 46.0578, 46.452, 46.8463, 47.2405, 47.6347, 48.0289,
                 48.4231, 48.883, 49.2773, 49.6715]
-Kb_10_over_y = [0.998106, 0.995265, 0.99053, 0.985795, 0.981061, 0.975379, 
+Kb_10_over_y = [0.998106, 0.995265, 0.99053, 0.985795, 0.981061, 0.975379,
                 0.969697, 0.963068, 0.957386, 0.950758, 0.945076, 0.938447,
                 0.930871, 0.925189, 0.918561, 0.910985, 0.904356, 0.897727,
-                0.891098, 0.883523, 0.876894, 0.870265, 0.862689, 0.856061, 
+                0.891098, 0.883523, 0.876894, 0.870265, 0.862689, 0.856061,
                 0.848485, 0.840909, 0.83428, 0.827652, 0.820076, 0.8125,
                 0.805871, 0.798295, 0.79072, 0.783144, 0.775568, 0.768939,
-                0.762311, 0.754735, 0.747159, 0.739583, 0.732008, 0.724432, 
+                0.762311, 0.754735, 0.747159, 0.739583, 0.732008, 0.724432,
                 0.716856, 0.70928, 0.701705, 0.695076]
 
 
@@ -567,10 +601,10 @@ def API520_A_g(m, T, Z, MW, k, P1, P2=101325, Kd=0.975, Kb=1, Kc=1):
 
     >>> API520_A_g(m=24270/3600., T=348., Z=0.90, MW=51., k=1.11, P1=670E3, P2=532E3, Kd=0.975, Kb=1, Kc=1)
     0.004248358775943481
-    
+
     The mass flux in (kg/(s*m^2)) can be found by dividing the specified mass
     flow by the calculated area:
-        
+
     >>> (24270/3600.)/API520_A_g(m=24270/3600., T=348., Z=0.90, MW=51., k=1.11, P1=670E3, Kb=1, Kc=1)
     1822.541960488834
 
